@@ -1,10 +1,10 @@
-__version__ = "0.6.8"
+__version__ = "0.6.10"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.6.8)'
+__git_branch__ = '(detached from v0.6.10)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '46c32e56bdca15955f2e11d0617f8afc994e3cf6'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '3b19e3996e39f181108de28af23f1d30fb763119'
+__git_head_subject__ = 'HOSTDEV-1699 python location on ftp'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
